class Endpoints:
    base_url = "https://api.heytextual.com"
    extract = f"{base_url}/extract"
    documents = f"{base_url}/documents"
    document = f"{base_url}/api/documents"
    templates = f"{base_url}/templates"



import requests
from .endpoints import Endpoints

class HeyTextualClient:
    def __init__(self, api_key):
        self.api_key = api_key
        self.headers = {
            "Authorization: Bearer {api_key}"
        }
        self.endpoints = Endpoints()

    def extract(self, file_path, template_id):
        with open(file_path, 'rb') as file:
            response = requests.post(
                self.endpoints.extract,
                headers=self.headers,
                files={'archivo': file},
                data={'template': template_id}
            )
        return response.json()

    def documents(self, start_date=None, end_date=None, limit=None):
        params = {
            "startDate": start_date,
            "endDate": end_date,
            "limit": limit
        }
        response = requests.post(
            self.endpoints.documents,
            headers=self.headers,
            data=params
        )
        return response.json()

    def document(self, document_id):
        response = requests.post(
            f"{self.endpoints.document}/{document_id}",
            headers=self.headers,
            data={'documentId': document_id}
        )
        return response.json()

    def templates(self, start_date=None, end_date=None, limit=None):
        params = {
            "startDate": start_date,
            "endDate": end_date,
            "limit": limit
        }
        response = requests.post(
            self.endpoints.templates,
            headers=self.headers,
            data=params
        )
        return response.json()



import unittest
from heytextual import HeyTextualClient

class TestHeyTextualClient(unittest.TestCase):
    def setUp(self):
        self.client = HeyTextualClient(api_key="your_test_api_key")

    def test_extract(self):
        # Add your test cases
        pass

    def test_documents(self):
        # Add your test cases
        pass

    def test_document(self):
        # Add your test cases
        pass

    def test_templates(self):
        # Add your test cases
        pass

if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

setup(
    name='heytextual',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    entry_points={
        'console_scripts': [
            'heytextual=heytextual:main',
        ],
    },
    author="Daniel Fernandez Gutierrez",
    author_email="dfernandez@heytextual.com",
    description="A Python SDK for the HeyTextual API",
    license="MIT",
    keywords="API SDK HEYTEXTUAL",
    url="https://github.com/danielfergu/heytextual-python",
)
